timely_parabolic_simulation library

Classes

TimelyParabolicSimulation
a no-nonsense sim that takes a fixed duration to transpire Fixed-duration ease from startValue to endValue that can be retargeted with target without velocity jumps. duration and the time argument to x, dx, and isDone share the same units (for example 1.0 for a normalized 0→1 progress curve, or microseconds as in the original easer).

Constants

kTimelyParabolicDefaultDurationSeconds → const double
Default segment length in seconds for TimelyParabolicSimulation's (current, target, velocity) constructor (matches common short layout moves).